# PreFab Models

`PreFab` accommodates unique *predictor* and *corrector* models for each photonic foundry, regularly updated based on recent fabrication data.

| Foundry | Process | Latest Version | Latest Dataset | Model Name | Model Tag | Status |
| ------- | ------- | -------------- | -------------- | ---------- |---------- | ------ |
| ANT | NanoSOI | v5 (Jun 3 2023) | d4 (Apr 12 2023) | ANT_NanoSOI | v5-d4 | Beta |
| ANT | SiN (Upper Edge) | v5 (Jun 3 2023) | d0 (Jun 1 2023) | ANT_SiN | v5-d0-upper | Alpha |
| ANT | SiN (Lower Edge) | v5 (Jun 3 2023) | d0 (Jun 1 2023) | ANT_SiN | v5-d0-lower | Alpha |
| SiEPICfab | SOI | v5 (Jun 3 2023) | d0 (Jun 14 2023) | SiEPICfab_SOI | v5-d0 | Alpha |

*New models and foundries are regularly added. Usage may change. For additional foundry and process models, feel free to contact us or raise an issue.*
